@@ -2,6 +2,7 @@
 using System.Collections.Generic;
 using System.Text;
 using System.Text.RegularExpressions;
+using System.Threading.Tasks;
 
 namespace SourceGit.Commands
 {
@@ -21,10 +22,10 @@ namespace SourceGit.Commands
             Args = "submodule status";
         }
 
-        public List<Models.Submodule> Result()
+        public async Task<List<Models.Submodule>> GetResultAsync()
         {
             var submodules = new List<Models.Submodule>();
-            var rs = ReadToEnd();
+            var rs = await ReadToEndAsync().ConfigureAwait(false);
 
             var lines = rs.StdOut.Split(['\r', '\n'], StringSplitOptions.RemoveEmptyEntries);
             var map = new Dictionary<string, Models.Submodule>();
@@ -64,11 +65,12 @@ namespace SourceGit.Commands
             if (submodules.Count > 0)
             {
                 Args = "config --file .gitmodules --list";
-                rs = ReadToEnd();
+                rs = await ReadToEndAsync().ConfigureAwait(false);
                 if (rs.IsSuccess)
                 {
                     var modules = new Dictionary<string, ModuleInfo>();
                     lines = rs.StdOut.Split(['\r', '\n'], StringSplitOptions.RemoveEmptyEntries);
+
                     foreach (var line in lines)
                     {
                         var match = REG_FORMAT_MODULE_INFO().Match(line);
@@ -80,21 +82,39 @@ namespace SourceGit.Commands
 
                             if (!modules.TryGetValue(name, out var m))
                             {
-                                m = new ModuleInfo();
-                                modules.Add(name, m);
+                                // Find name alias.
+                                foreach (var kv in modules)
+                                {
+                                    if (kv.Value.Path.Equals(name, StringComparison.Ordinal))
+                                    {
+                                        m = kv.Value;
+                                        break;
+                                    }
+                                }
+
+                                if (m == null)
+                                {
+                                    m = new ModuleInfo();
+                                    modules.Add(name, m);
+                                }
                             }
 
                             if (key.Equals("path", StringComparison.Ordinal))
                                 m.Path = val;
                             else if (key.Equals("url", StringComparison.Ordinal))
                                 m.URL = val;
+                            else if (key.Equals("branch", StringComparison.Ordinal))
+                                m.Branch = val;
                         }
                     }
 
                     foreach (var kv in modules)
                     {
                         if (map.TryGetValue(kv.Value.Path, out var m))
+                        {
                             m.URL = kv.Value.URL;
+                            m.Branch = kv.Value.Branch;
+                        }
                     }
                 }
             }
@@ -105,15 +125,11 @@ namespace SourceGit.Commands
                 foreach (var kv in map)
                 {
                     if (kv.Value.Status == Models.SubmoduleStatus.Normal)
-                    {
-                        builder.Append('"');
-                        builder.Append(kv.Key);
-                        builder.Append("\" ");
-                    }
+                        builder.Append(kv.Key.Quoted()).Append(' ');
                 }
 
                 Args = $"--no-optional-locks status --porcelain -- {builder}";
-                rs = ReadToEnd();
+                rs = await ReadToEndAsync().ConfigureAwait(false);
                 if (!rs.IsSuccess)
                     return submodules;
 
@@ -137,6 +153,7 @@ namespace SourceGit.Commands
         {
             public string Path { get; set; } = string.Empty;
             public string URL { get; set; } = string.Empty;
+            public string Branch { get; set; } = "HEAD";
         }
     }
 }
