@@ -12,14 +12,15 @@ namespace SourceGit.Models
 {
     public class ExternalTool
     {
-        public string Name { get; private set; }
-        public Bitmap IconImage { get; private set; } = null;
+        public string Name { get; }
+        public string ExecFile { get; }
+        public Bitmap IconImage { get; }
 
         public ExternalTool(string name, string icon, string execFile, Func<string, string> execArgsGenerator = null)
         {
             Name = name;
-            _execFile = execFile;
-            _execArgsGenerator = execArgsGenerator ?? (repo => $"\"{repo}\"");
+            ExecFile = execFile;
+            _execArgsGenerator = execArgsGenerator ?? (repo => repo.Quoted());
 
             try
             {
@@ -38,16 +39,27 @@ namespace SourceGit.Models
             Process.Start(new ProcessStartInfo()
             {
                 WorkingDirectory = repo,
-                FileName = _execFile,
+                FileName = ExecFile,
                 Arguments = _execArgsGenerator.Invoke(repo),
                 UseShellExecute = false,
             });
         }
 
-        private string _execFile = string.Empty;
         private Func<string, string> _execArgsGenerator = null;
     }
 
+    public class VisualStudioInstance
+    {
+        [JsonPropertyName("displayName")]
+        public string DisplayName { get; set; } = string.Empty;
+
+        [JsonPropertyName("productPath")]
+        public string ProductPath { get; set; } = string.Empty;
+
+        [JsonPropertyName("isPrerelease")]
+        public bool IsPrerelease { get; set; } = false;
+    }
+
     public class JetBrainsState
     {
         [JsonPropertyName("version")]
@@ -88,7 +100,7 @@ namespace SourceGit.Models
 
     public class ExternalToolsFinder
     {
-        public List<ExternalTool> Founded
+        public List<ExternalTool> Tools
         {
             get;
             private set;
@@ -100,7 +112,10 @@ namespace SourceGit.Models
             try
             {
                 if (File.Exists(customPathsConfig))
-                    _customPaths = JsonSerializer.Deserialize(File.ReadAllText(customPathsConfig), JsonCodeGen.Default.ExternalToolPaths);
+                {
+                    using var stream = File.OpenRead(customPathsConfig);
+                    _customPaths = JsonSerializer.Deserialize(stream, JsonCodeGen.Default.ExternalToolPaths);
+                }
             }
             catch
             {
@@ -114,13 +129,13 @@ namespace SourceGit.Models
         {
             if (_customPaths.Tools.TryGetValue(name, out var customPath) && File.Exists(customPath))
             {
-                Founded.Add(new ExternalTool(name, icon, customPath, execArgsGenerator));
+                Tools.Add(new ExternalTool(name, icon, customPath, execArgsGenerator));
             }
             else
             {
                 var path = finder();
                 if (!string.IsNullOrEmpty(path) && File.Exists(path))
-                    Founded.Add(new ExternalTool(name, icon, path, execArgsGenerator));
+                    Tools.Add(new ExternalTool(name, icon, path, execArgsGenerator));
             }
         }
 
@@ -154,22 +169,28 @@ namespace SourceGit.Models
             TryAdd("Zed", "zed", platformFinder);
         }
 
+        public void Cursor(Func<string> platformFinder)
+        {
+            TryAdd("Cursor", "cursor", platformFinder);
+        }
+
         public void FindJetBrainsFromToolbox(Func<string> platformFinder)
         {
             var exclude = new List<string> { "fleet", "dotmemory", "dottrace", "resharper-u", "androidstudio" };
-            var supported_icons = new List<string> { "CL", "DB", "DL", "DS", "GO", "JB", "PC", "PS", "PY", "QA", "QD", "RD", "RM", "RR", "WRS", "WS" };
+            var supportedIcons = new List<string> { "CL", "DB", "DL", "DS", "GO", "JB", "PC", "PS", "PY", "QA", "QD", "RD", "RM", "RR", "WRS", "WS" };
             var state = Path.Combine(platformFinder(), "state.json");
             if (File.Exists(state))
             {
-                var stateData = JsonSerializer.Deserialize(File.ReadAllText(state), JsonCodeGen.Default.JetBrainsState);
+                using var stream = File.OpenRead(state);
+                var stateData = JsonSerializer.Deserialize(stream, JsonCodeGen.Default.JetBrainsState);
                 foreach (var tool in stateData.Tools)
                 {
                     if (exclude.Contains(tool.ToolId.ToLowerInvariant()))
                         continue;
 
-                    Founded.Add(new ExternalTool(
+                    Tools.Add(new ExternalTool(
                         $"{tool.DisplayName} {tool.DisplayVersion}",
-                        supported_icons.Contains(tool.ProductCode) ? $"JetBrains/{tool.ProductCode}" : "JetBrains/JB",
+                        supportedIcons.Contains(tool.ProductCode) ? $"JetBrains/{tool.ProductCode}" : "JetBrains/JB",
                         Path.Combine(tool.InstallLocation, tool.LaunchCommand)));
                 }
             }
