@@ -48,33 +48,35 @@ namespace SourceGit.Native
 
         public List<Models.ExternalTool> FindExternalTools()
         {
+            var localAppDataDir = Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData);
             var finder = new Models.ExternalToolsFinder();
             finder.VSCode(() => FindExecutable("code"));
             finder.VSCodeInsiders(() => FindExecutable("code-insiders"));
             finder.VSCodium(() => FindExecutable("codium"));
-            finder.Fleet(FindJetBrainsFleet);
-            finder.FindJetBrainsFromToolbox(() => $"{Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData)}/JetBrains/Toolbox");
+            finder.Cursor(() => FindExecutable("cursor"));
+            finder.Fleet(() => FindJetBrainsFleet(localAppDataDir));
+            finder.FindJetBrainsFromToolbox(() => Path.Combine(localAppDataDir, "JetBrains/Toolbox"));
             finder.SublimeText(() => FindExecutable("subl"));
             finder.Zed(() => FindExecutable("zeditor"));
-            return finder.Founded;
+            return finder.Tools;
         }
 
         public void OpenBrowser(string url)
         {
-            Process.Start("xdg-open", $"\"{url}\"");
+            Process.Start("xdg-open", url.Quoted());
         }
 
         public void OpenInFileManager(string path, bool select)
         {
             if (Directory.Exists(path))
             {
-                Process.Start("xdg-open", $"\"{path}\"");
+                Process.Start("xdg-open", path.Quoted());
             }
             else
             {
                 var dir = Path.GetDirectoryName(path);
                 if (Directory.Exists(dir))
-                    Process.Start("xdg-open", $"\"{dir}\"");
+                    Process.Start("xdg-open", dir.Quoted());
             }
         }
 
@@ -89,9 +91,9 @@ namespace SourceGit.Native
             startInfo.FileName = terminal;
 
             if (terminal.EndsWith("wezterm", StringComparison.OrdinalIgnoreCase))
-                startInfo.Arguments = $"start --cwd \"{cwd}\"";
+                startInfo.Arguments = $"start --cwd {cwd.Quoted()}";
             else if (terminal.EndsWith("ptyxis", StringComparison.OrdinalIgnoreCase))
-                startInfo.Arguments = $"--new-window --working-directory=\"{cwd}\"";
+                startInfo.Arguments = $"--new-window --working-directory={cwd.Quoted()}";
 
             try
             {
@@ -105,13 +107,13 @@ namespace SourceGit.Native
 
         public void OpenWithDefaultEditor(string file)
         {
-            var proc = Process.Start("xdg-open", $"\"{file}\"");
+            var proc = Process.Start("xdg-open", file.Quoted());
             if (proc != null)
             {
                 proc.WaitForExit();
 
                 if (proc.ExitCode != 0)
-                    App.RaiseException("", $"Failed to open \"{file}\"");
+                    App.RaiseException("", $"Failed to open: {file}");
 
                 proc.Close();
             }
@@ -131,9 +133,9 @@ namespace SourceGit.Native
             return string.Empty;
         }
 
-        private string FindJetBrainsFleet()
+        private string FindJetBrainsFleet(string localAppDataDir)
         {
-            var path = $"{Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData)}/JetBrains/Toolbox/apps/fleet/bin/Fleet";
+            var path = Path.Combine(localAppDataDir, "JetBrains/Toolbox/apps/fleet/bin/Fleet");
             return File.Exists(path) ? path : FindExecutable("fleet");
         }
     }
