@@ -21,7 +21,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            _repo.SetWatcherEnabled(false);
+            using var lockWatcher = _repo.LockWatcher();
             ProgressDescription = "Fetching LFS objects from remote ...";
 
             var log = _repo.CreateLog("LFS Fetch");
@@ -32,7 +32,6 @@ namespace SourceGit.ViewModels
                 .FetchAsync(SelectedRemote.Name);
 
             log.Complete();
-            _repo.SetWatcherEnabled(true);
             return true;
         }
 
