@@ -1,4 +1,5 @@
-﻿using System.Collections.Generic;
+﻿using System;
+using System.Collections.Generic;
 using System.Threading.Tasks;
 
 using Avalonia.Collections;
@@ -114,8 +115,8 @@ namespace SourceGit.ViewModels
 
         public AvaloniaList<Models.IssueTracker> IssueTrackers
         {
-            get => _repo.IssueTrackers;
-        }
+            get;
+        } = [];
 
         public Models.IssueTracker SelectedIssueTracker
         {
@@ -161,7 +162,7 @@ namespace SourceGit.ViewModels
             if (!AvailableOpenAIServices.Contains(PreferredOpenAIService))
                 PreferredOpenAIService = "---";
 
-            _cached = new Commands.Config(repo.FullPath).ReadAllAsync().Result;
+            _cached = new Commands.Config(repo.FullPath).ReadAll();
             if (_cached.TryGetValue("user.name", out var name))
                 UserName = name;
             if (_cached.TryGetValue("user.email", out var email))
@@ -176,6 +177,17 @@ namespace SourceGit.ViewModels
                 HttpProxy = proxy;
             if (_cached.TryGetValue("fetch.prune", out var prune))
                 EnablePruneOnFetch = (prune == "true");
+
+            foreach (var rule in _repo.IssueTrackers)
+            {
+                IssueTrackers.Add(new()
+                {
+                    IsShared = rule.IsShared,
+                    Name = rule.Name,
+                    RegexString = rule.RegexString,
+                    URLTemplate = rule.URLTemplate,
+                });
+            }
         }
 
         public void ClearHttpProxy()
@@ -208,25 +220,28 @@ namespace SourceGit.ViewModels
             return outs;
         }
 
-        public async Task AddIssueTrackerAsync(string name, string regex, string url)
+        public void AddIssueTracker(string name, string regex, string url)
         {
-            SelectedIssueTracker = await _repo.AddIssueTrackerAsync(name, regex, url);
+            var rule = new Models.IssueTracker()
+            {
+                IsShared = false,
+                Name = name,
+                RegexString = regex,
+                URLTemplate = url,
+            };
+
+            IssueTrackers.Add(rule);
+            SelectedIssueTracker = rule;
         }
 
-        public async Task RemoveIssueTrackerAsync()
+        public void RemoveIssueTracker()
         {
             if (_selectedIssueTracker is { } rule)
-                await _repo.RemoveIssueTrackerAsync(rule);
+                IssueTrackers.Remove(rule);
 
             SelectedIssueTracker = null;
         }
 
-        public async Task ChangeIssueTrackerShareModeAsync()
-        {
-            if (_selectedIssueTracker is { } rule)
-                await _repo.ChangeIssueTrackerShareModeAsync(rule);
-        }
-
         public void AddNewCustomAction()
         {
             SelectedCustomAction = _repo.Settings.AddNewCustomAction();
@@ -259,6 +274,8 @@ namespace SourceGit.ViewModels
             await SetIfChangedAsync("user.signingkey", GPGUserSigningKey, "");
             await SetIfChangedAsync("http.proxy", HttpProxy, "");
             await SetIfChangedAsync("fetch.prune", EnablePruneOnFetch ? "true" : "false", "false");
+
+            await ApplyIssueTrackerChangesAsync();
         }
 
         private async Task SetIfChangedAsync(string key, string value, string defValue)
@@ -267,6 +284,62 @@ namespace SourceGit.ViewModels
                 await new Commands.Config(_repo.FullPath).SetAsync(key, value);
         }
 
+        private async Task ApplyIssueTrackerChangesAsync()
+        {
+            var changed = false;
+            var oldRules = new Dictionary<string, Models.IssueTracker>();
+            foreach (var rule in _repo.IssueTrackers)
+                oldRules.Add(rule.Name, rule);
+
+            foreach (var rule in IssueTrackers)
+            {
+                if (oldRules.TryGetValue(rule.Name, out var old))
+                {
+                    if (old.IsShared != rule.IsShared)
+                    {
+                        changed = true;
+                        await new Commands.IssueTracker(_repo.FullPath, old.IsShared).RemoveAsync(old.Name);
+                        await new Commands.IssueTracker(_repo.FullPath, rule.IsShared).AddAsync(rule);
+                    }
+                    else
+                    {
+                        if (!old.RegexString.Equals(rule.RegexString, StringComparison.Ordinal))
+                        {
+                            changed = true;
+                            await new Commands.IssueTracker(_repo.FullPath, old.IsShared).UpdateRegexAsync(rule);
+                        }
+
+                        if (!old.URLTemplate.Equals(rule.URLTemplate, StringComparison.Ordinal))
+                        {
+                            changed = true;
+                            await new Commands.IssueTracker(_repo.FullPath, old.IsShared).UpdateURLTemplateAsync(rule);
+                        }
+                    }
+
+                    oldRules.Remove(rule.Name);
+                }
+                else
+                {
+                    changed = true;
+                    await new Commands.IssueTracker(_repo.FullPath, rule.IsShared).AddAsync(rule);
+                }
+            }
+
+            if (oldRules.Count > 0)
+            {
+                changed = true;
+
+                foreach (var kv in oldRules)
+                    await new Commands.IssueTracker(_repo.FullPath, kv.Value.IsShared).RemoveAsync(kv.Key);
+            }
+
+            if (changed)
+            {
+                _repo.IssueTrackers.Clear();
+                _repo.IssueTrackers.AddRange(IssueTrackers);
+            }
+        }
+
         private readonly Repository _repo = null;
         private readonly Dictionary<string, string> _cached = null;
         private string _httpProxy;
