@@ -30,7 +30,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            _repo.SetWatcherEnabled(false);
+            using var lockWatcher = _repo.LockWatcher();
             ProgressDescription = $"Reset current branch to {To.SHA} ...";
 
             var log = _repo.CreateLog($"Reset HEAD to '{To.SHA}'");
@@ -41,7 +41,6 @@ namespace SourceGit.ViewModels
                 .ExecAsync();
 
             log.Complete();
-            _repo.SetWatcherEnabled(true);
             return succ;
         }
 
