@@ -14,7 +14,7 @@ using AvaloniaEdit.TextMate;
 
 namespace SourceGit.Views
 {
-    public class CommandLogContentPresenter : TextEditor
+    public class CommandLogContentPresenter : TextEditor, Models.ICommandLogReceiver
     {
         public class LineStyleTransformer : DocumentColorizingTransformer
         {
@@ -95,6 +95,12 @@ namespace SourceGit.Views
             TextArea.TextView.Options.EnableEmailHyperlinks = false;
         }
 
+        public void OnReceiveCommandLog(string line)
+        {
+            AppendText("\n");
+            AppendText(line);
+        }
+
         protected override void OnLoaded(RoutedEventArgs e)
         {
             base.OnLoaded(e);
@@ -126,10 +132,13 @@ namespace SourceGit.Views
 
             if (change.Property == LogProperty)
             {
-                if (change.NewValue is ViewModels.CommandLog log)
+                if (change.OldValue is ViewModels.CommandLog oldLog)
+                    oldLog.Unsubscribe(this);
+
+                if (change.NewValue is ViewModels.CommandLog newLog)
                 {
-                    Text = log.Content;
-                    log.Register(OnLogLineReceived);
+                    Text = newLog.Content;
+                    newLog.Subscribe(this);
                 }
                 else
                 {
@@ -143,12 +152,6 @@ namespace SourceGit.Views
             }
         }
 
-        private void OnLogLineReceived(string newline)
-        {
-            AppendText("\n");
-            AppendText(newline);
-        }
-
         private TextMate.Installation _textMate = null;
     }
 }
