@@ -20,9 +20,8 @@ namespace SourceGit.Views
             if (DataContext is ViewModels.RevisionCompare { SelectedChanges: { Count: 1 } selected } vm &&
                 sender is ChangeCollectionView view)
             {
-                var repo = vm.RepositoryPath;
                 var change = selected[0];
-                var changeFullPath = Native.OS.GetAbsPath(repo, change.Path);
+                var changeFullPath = vm.GetAbsPath(change.Path);
                 var menu = new ContextMenu();
 
                 var openWithMerger = new MenuItem();
@@ -65,13 +64,13 @@ namespace SourceGit.Views
                 copyFullPath.Header = App.Text("CopyFullPath");
                 copyFullPath.Icon = App.CreateMenuIcon("Icons.Copy");
                 copyFullPath.Tag = OperatingSystem.IsMacOS() ? "⌘+⇧+C" : "Ctrl+Shift+C";
-                copyFullPath.Click += async (_, e) =>
+                copyFullPath.Click += async (_, ev) =>
                 {
                     await App.CopyTextAsync(changeFullPath);
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
                 menu.Items.Add(copyFullPath);
-                menu?.Open(view);
+                menu.Open(view);
             }
 
             e.Handled = true;
@@ -105,5 +104,25 @@ namespace SourceGit.Views
 
             e.Handled = true;
         }
+
+        private async void OnChangeCollectionViewKeyDown(object sender, KeyEventArgs e)
+        {
+            if (DataContext is not ViewModels.RevisionCompare vm)
+                return;
+
+            if (sender is not ChangeCollectionView { SelectedChanges: { Count: 1 } selectedChanges })
+                return;
+
+            var change = selectedChanges[0];
+            if (e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control) && e.Key == Key.C)
+            {
+                if (e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                    await App.CopyTextAsync(vm.GetAbsPath(change.Path));
+                else
+                    await App.CopyTextAsync(change.Path);
+
+                e.Handled = true;
+            }
+        }
     }
 }
