@@ -71,7 +71,7 @@ namespace SourceGit.Views
                 var patch = new MenuItem();
                 patch.Header = App.Text("StashCM.SaveAsPatch");
                 patch.Icon = App.CreateMenuIcon("Icons.Diff");
-                patch.Click += async (_, e) =>
+                patch.Click += async (_, ev) =>
                 {
                     var storageProvider = TopLevel.GetTopLevel(this)?.StorageProvider;
                     if (storageProvider == null)
@@ -86,7 +86,7 @@ namespace SourceGit.Views
                     if (storageFile != null)
                         await vm.SaveStashAsPathAsync(stash, storageFile.Path.LocalPath);
 
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
 
                 var copy = new MenuItem();
@@ -126,8 +126,8 @@ namespace SourceGit.Views
             if (DataContext is ViewModels.StashesPage { SelectedChanges: { Count: 1 } selected } vm &&
                 sender is ChangeCollectionView view)
             {
-                var repo = vm.RepositoryPath;
                 var change = selected[0];
+                var fullPath = vm.GetAbsPath(change.Path);
 
                 var openWithMerger = new MenuItem();
                 openWithMerger.Header = App.Text("OpenInExternalMergeTool");
@@ -139,7 +139,6 @@ namespace SourceGit.Views
                     ev.Handled = true;
                 };
 
-                var fullPath = Native.OS.GetAbsPath(repo, change.Path);
                 var explore = new MenuItem();
                 explore.Header = App.Text("RevealFile");
                 explore.Icon = App.CreateMenuIcon("Icons.Explore");
@@ -173,10 +172,10 @@ namespace SourceGit.Views
                 copyFullPath.Header = App.Text("CopyFullPath");
                 copyFullPath.Icon = App.CreateMenuIcon("Icons.Copy");
                 copyFullPath.Tag = OperatingSystem.IsMacOS() ? "⌘+⇧+C" : "Ctrl+Shift+C";
-                copyFullPath.Click += async (_, e) =>
+                copyFullPath.Click += async (_, ev) =>
                 {
                     await App.CopyTextAsync(fullPath);
-                    e.Handled = true;
+                    ev.Handled = true;
                 };
 
                 var menu = new ContextMenu();
@@ -192,5 +191,25 @@ namespace SourceGit.Views
 
             e.Handled = true;
         }
+
+        private async void OnChangeCollectionViewKeyDown(object sender, KeyEventArgs e)
+        {
+            if (DataContext is not ViewModels.StashesPage vm)
+                return;
+
+            if (sender is not ChangeCollectionView { SelectedChanges: { Count: 1 } selectedChanges })
+                return;
+
+            var change = selectedChanges[0];
+            if (e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control) && e.Key == Key.C)
+            {
+                if (e.KeyModifiers.HasFlag(KeyModifiers.Shift))
+                    await App.CopyTextAsync(vm.GetAbsPath(change.Path));
+                else
+                    await App.CopyTextAsync(change.Path);
+
+                e.Handled = true;
+            }
+        }
     }
 }
